Package: scaledescr
Type: Package
Title: Descriptive, Reliability, and Inferential Tables for
        Psychometric Scales and Demographic Data
Version: 0.2.7
Authors@R: 
    person(
      given  = "Darshankumar",
      family = "Dharaiya",
      email  = "dharaiya.darshan@gmail.com",
      role   = c("aut", "cre"),
      comment = c(ORCID = "0009-0009-9351-8602")
    )
Description: Provides functions to format and summarise already computed 
    outputs from commonly used statistical and psychometric functions into 
    compact, single-row tables and simple graphs, with utilities to export 
    results to CSV, Word, and Excel formats. The package does not implement 
    new statistical methods or estimation procedures; instead, it organises 
    and presents results obtained from existing packages such as 'psych', 
    'stats', 'gtsummary', and 'lavaan' to streamline reporting workflows in 
    clinical and psychological research.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: dplyr, gtsummary, purrr, rlang, stats, officer, openxlsx,
        utils, psych, stringr, flextable, lavaan
Suggests: testthat (>= 3.0.0), webshot2
Config/testthat/edition: 3
NeedsCompilation: no
Author: Darshankumar Dharaiya [aut, cre] (ORCID:
    <https://orcid.org/0009-0009-9351-8602>)
Maintainer: Darshankumar Dharaiya <dharaiya.darshan@gmail.com>
Packaged: 2026-06-10 12:33:27 UTC; HP
Repository: CRAN
Date/Publication: 2026-06-10 13:20:02 UTC
Built: R 4.5.2; ; 2026-06-10 15:58:24 UTC; unix

Package: scaledescr
Type: Package
Title: Descriptive, Reliability, and Inferential Tables for
        Psychometric Scales and Demographic Data
Version: 0.2.7
Authors@R: 
    person(
      given  = "Darshankumar",
      family = "Dharaiya",
      email  = "dharaiya.darshan@gmail.com",
      role   = c("aut", "cre"),
      comment = c(ORCID = "0009-0009-9351-8602")
    )
Description: Provides functions to format and summarise already computed 
    outputs from commonly used statistical and psychometric functions into 
    compact, single-row tables and simple graphs, with utilities to export 
    results to CSV, Word, and Excel formats. The package does not implement 
    new statistical methods or estimation procedures; instead, it organises 
    and presents results obtained from existing packages such as 'psych', 
    'stats', 'gtsummary', and 'lavaan' to streamline reporting workflows in 
    clinical and psychological research.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: dplyr, gtsummary, purrr, rlang, stats, officer, openxlsx,
        utils, psych, stringr, flextable, lavaan
Suggests: testthat (>= 3.0.0), webshot2
Config/testthat/edition: 3
NeedsCompilation: no
Author: Darshankumar Dharaiya [aut, cre] (ORCID:
    <https://orcid.org/0009-0009-9351-8602>)
Maintainer: Darshankumar Dharaiya <dharaiya.darshan@gmail.com>
Packaged: 2026-06-10 12:33:27 UTC; HP
Repository: CRAN
Date/Publication: 2026-06-10 13:20:02 UTC
Built: R 4.6.0; ; 2026-06-10 14:30:21 UTC; unix

# Generated by roxygen2: do not edit by hand

export(compute_ICC)
export(make_EFA_factorability_table)
export(make_alpha_table)
export(make_alphanumeric_conversion)
export(make_chisq_test_table)
export(make_citation_to_output)
export(make_correlation_table)
export(make_dataframe_to_output)
export(make_demographic_table)
export(make_demographic_table_to_output)
export(make_independent_t_test_table)
export(make_lavaan_analysis_tables)
export(make_lavaan_mediation_tables)
export(make_normality_table)
export(make_one_sample_t_test_table)
export(make_paired_t_test_table)
export(make_reverse_score)
export(make_scale_description_table)
export(make_scale_total)
importFrom(dplyr,"%>%")
importFrom(dplyr,all_of)
importFrom(dplyr,select)
importFrom(flextable,autofit)
importFrom(flextable,flextable)
importFrom(flextable,font)
importFrom(flextable,gen_grob)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grid,grid.draw)
importFrom(grid,popViewport)
importFrom(grid,pushViewport)
importFrom(grid,viewport)
importFrom(gtsummary,all_categorical)
importFrom(gtsummary,all_continuous)
importFrom(gtsummary,tbl_summary)
importFrom(lavaan,fitMeasures)
importFrom(lavaan,lavInspect)
importFrom(lavaan,parameterEstimates)
importFrom(lavaan,sem)
importFrom(lavaan,standardizedSolution)
importFrom(officer,body_add_par)
importFrom(officer,body_add_table)
importFrom(officer,read_docx)
importFrom(openxlsx,write.xlsx)
importFrom(psych,ICC)
importFrom(psych,KMO)
importFrom(psych,cortest.bartlett)
importFrom(purrr,map_chr)
importFrom(purrr,map_lgl)
importFrom(rlang,as_name)
importFrom(rlang,enquos)
importFrom(stats,cor.test)
importFrom(stats,ks.test)
importFrom(stats,na.omit)
importFrom(stats,sd)
importFrom(stats,shapiro.test)
importFrom(stats,t.test)
importFrom(stringr,str_to_title)
importFrom(stringr,str_trim)
importFrom(utils,capture.output)
importFrom(utils,citation)
importFrom(utils,combn)
importFrom(utils,packageVersion)
importFrom(utils,sessionInfo)
importFrom(utils,write.csv)

#' Export Session Package Citations to Multiple Formats
#'
#' This function identifies all currently loaded external packages in the current R session,
#' along with base R, and extracts their citation information. It generates both
#' plain text and BibTeX formats and exports them using the package's internal
#' export utility.
#'
#' @param filename A character string specifying the name of the output file.
#'   Defaults to "Session_Citations".
#' @param format A character string specifying the output format:
#'   "csv", "word", "excel", or "pdf". Defaults to "csv".
#' @param path A character string specifying the directory path for the output.
#'   If NULL (default), it uses a temporary directory. Use "getwd()" for the
#'   current working directory.
#' @param packages A character vector of package names to extract citations for.
#'   If NULL (default), citations are extracted for all currently loaded packages
#'   in the session, including base R. Example: \code{packages = c("lavaan", "psych")}.
#'
#' @return The file path of the created document (invisibly).
#'
#' @examples
#' \dontrun{
#' # Export citations for currently loaded packages to a docs
#' make_citation_to_output(filename = "My_References", format = "word")
#'
#' # Export citations for selected packages to a docs in current working directory
#' make_citation_to_output( packages = c("base","psych","ggplot2"),
#'                          filename = "Selected_References",
#'                          format = "word",
#'                          path = getwd())
#'
#'
#' # Export to Excel in the current working directory
#' make_citation_to_output(format = "excel", path = "getwd()")
#'
#' }
#'
#' @importFrom utils sessionInfo citation capture.output packageVersion
#' @export
make_citation_to_output <- function(filename = "Session_Citations",
                                    format = "csv",
                                    path = NULL,
                                    packages = NULL) {
  # 1. Identify packages
  if (is.null(packages)) {
    pkgs <- c("base", names(sessionInfo()$otherPkgs))
  } else {
    pkgs <- packages
  }

  # 2. Extract Citation Data
  citation_list <- lapply(pkgs, function(p) {

    text_cit <- tryCatch({
      cit <- citation(p)
      paste(format(cit, style = "text"), collapse = " ")
    }, error = function(e) NA_character_)

    bib_cit <- tryCatch({
      cit <- citation(p)
      paste(utils::capture.output(print(utils::toBibtex(cit))), collapse = "\n")
    }, error = function(e) NA_character_)

    ver <- tryCatch(
      as.character(utils::packageVersion(p)),
      error = function(e) NA_character_
    )

    data.frame(
      Package       = p,
      Version       = ver,
      Citation_Text = text_cit,
      BibTeX        = bib_cit,
      stringsAsFactors = FALSE
    )
  })

  citation_df <- do.call(rbind, citation_list)

  # 3. Export
  scaledescr::make_dataframe_to_output(
    data = citation_df,
    filename = filename,
    format = format,
    path = path
  )
}

#' Export a data frame to CSV, Word (.docx),Excel (.xlsx) or pdf format.
#'
#' If no output path is specified, the file is written to a temporary directory
#' using `tempdir()`.
#' For reproducible workflows, users are encouraged to explicitly specify an output location, either the current working directory
#' or a full file path.
#'
#' - CSV files are written using `utils::write.csv()`
#' - Word files (`docx`) are created using the `officer` package
#' - Excel (`xlsx`) files are created using the `openxlsx` package
#' - PDF files are created using the 'flextable' package
#'
#' @param data A data frame to export.
#' @param filename Optional base file name (without extension). Defaults to object name.
#' (without path and without extension).
#' If not provided, the name of the input object is used.
#' @param format Character string specifying the output format. One of
#'   `"csv"`, `"word"`,`"excel"` or `"pdf"`. Default is `"csv"`.
#' @param path Optional character string specifying the directory where the
#'   file should be saved. If `NULL` (default), the file is written to a
#'   temporary directory. Use `path = getwd()` to save the file in the current
#'   working directory, or provide a full directory path.
#' @return Invisibly returns the full file path to the generated output file.
#' @note Exporting to PDF requires the 'webshot2' package to be installed.
#' @export
#' @importFrom utils write.csv
#' @importFrom officer read_docx body_add_par body_add_table
#' @importFrom openxlsx write.xlsx
#' @importFrom flextable flextable gen_grob font autofit
#' @importFrom grDevices pdf dev.off
#' @importFrom grid viewport pushViewport popViewport grid.draw
#'
#' @examples
#' \dontrun{
#'
#' # Example dataset available in base R
#' data_df <- head(mtcars)
#'
#' #--------------------------------------------------
#' # 1. Simplest use: export to CSV in temp directory
#' #--------------------------------------------------
#' make_dataframe_to_output(data_df)
#'
#' #--------------------------------------------------
#' # 2. Specify filename
#' #--------------------------------------------------
#' make_dataframe_to_output(
#'   data = data_df,
#'   filename = "mtcars_sample"
#' )
#'
#' #--------------------------------------------------
#' # 3. Export as Word document
#' #--------------------------------------------------
#' make_dataframe_to_output(
#'   data = data_df,
#'   filename = "mtcars_word_table",
#'   format = "word"
#' )
#'
#' #--------------------------------------------------
#' # 4. Export as Excel file
#' #--------------------------------------------------
#' make_dataframe_to_output(
#'   data = data_df,
#'   filename = "mtcars_excel_table",
#'   format = "excel"
#' )
#'
#' #--------------------------------------------------
#' # 5. Save to current working directory
#' #--------------------------------------------------
#' make_dataframe_to_output(
#'   data = data_df,
#'   filename = "mtcars_current_folder",
#'   format = "csv",
#'   path = "getwd()"
#' )
#'
#' #--------------------------------------------------
#' # 6. Save Excel file to current working directory
#' #--------------------------------------------------
#' make_dataframe_to_output(
#'   data = data_df,
#'   filename = "mtcars_excel_current",
#'   format = "excel",
#'   path = "getwd()"
#' )
#'
#' #--------------------------------------------------
#' # 7. Export another base dataset (iris)
#' #--------------------------------------------------
#' make_dataframe_to_output(
#'   data = head(iris),
#'   filename = "iris_sample",
#'   format = "word"
#' )
#'
#' #--------------------------------------------------
#' # 8. Using a custom folder path
#' #--------------------------------------------------
#' make_dataframe_to_output(
#'   data = head(airquality),
#'   filename = "airquality_data",
#'   format = "excel",
#'   path = "D:/output_folder"
#' )
#'
#' }


make_dataframe_to_output <- function( data,
                                      filename = NULL,
                                      format = "csv",
                                      path = NULL)
{ if (!is.data.frame(data)) stop("Input must be a data frame", call. = FALSE)

  # Validate format
  format <- tolower(format)
  if (!format %in% c("csv", "word", "excel","pdf")) {
    stop("Format must be one of 'csv', 'word', or 'excel', or 'pdf'.", call. = FALSE)
  }

  # Default filename
  if (is.null(filename)) {
    filename <- make.names(deparse(substitute(data)))
  }
  filename <- make.names(filename)  # ensure safe filename

  # Determine output directory
  if (is.null(path)) {
    out_dir <- tempdir()
  }
  else if (identical(path, "getwd()"))
  {    out_dir <- getwd()
  }
  else {
    out_dir <- path
  }
  if (!dir.exists(out_dir)) stop("Directory does not exist: ", out_dir, call. = FALSE)

  # Construct full file path
  ext <- switch(format,
                "excel" = "xlsx",
                "word"  = "docx",
                "pdf"   = "pdf",
                "csv")
  filepath <- file.path(out_dir, paste0(filename, ".", ext))

  # Export based on format
  if (format == "csv") {
    utils::write.csv(data, filepath, row.names = FALSE, fileEncoding = "UTF-8")
  }
  else if (format == "word") {
    if (!requireNamespace("officer", quietly = TRUE)) {
      stop("Please install the 'officer' package to export Word documents.", call. = FALSE)
    }
    colnames(data) <- make.names(colnames(data))
    doc <- officer::read_docx()
    doc <- officer::body_add_par(doc, filename, style = "heading 1")
    doc <- officer::body_add_table(doc, value = data)
    print(doc, target = filepath)
  }
  else if (format == "excel") {
    if (!requireNamespace("openxlsx", quietly = TRUE)) {
      stop("Please install the 'openxlsx' package to export Excel files.", call. = FALSE)
    }
    # Write Excel
    openxlsx::write.xlsx(data, file = filepath, rowNames = FALSE)
  }
  else if (format == "pdf") {

    if (!requireNamespace("flextable", quietly = TRUE)) {
      stop("Please install the 'flextable' package for PDF export.", call. = FALSE)
    }

    # ---- Branch condition ----
    is_citation_df <- all(c("Citation_Text", "BibTeX") %in% names(data))

    # ---- Warning early ----
    if (is_citation_df) {
      warning(
        "PDF export for citation tables may render poorly due to long text fields.
      Consider using format = 'docx' and converting to PDF for better results.",
        call. = FALSE
      )
    }

    # ---- Build flextable differently based on data ----
    if (is_citation_df) {
      ft <- flextable::flextable(data)
      ft <- flextable::font(ft, fontname = "sans", part = "all")
      ft <- flextable::fontsize(ft, size = 7, part = "all")   # smaller text
      ft <- flextable::autofit(ft)

      # safer grob (avoid layout stress)
      table_grob <- flextable::gen_grob(ft)

      use_viewport <- FALSE   # 🚨 disable viewport for this case

    } else {
      ft <- flextable::flextable(data)
      ft <- flextable::font(ft, fontname = "sans", part = "all")
      ft <- flextable::autofit(ft)

      table_grob <- flextable::gen_grob(ft, fit = "width", scaling = "min")

      use_viewport <- TRUE
    }

    # ---- Open PDF ----
    grDevices::pdf(file = filepath, width = 8.27, height = 11.69)
    grid::grid.newpage()

    # ---- Conditional drawing ----
    if (use_viewport) {
      margin_window <- grid::viewport(
        width = 0.9,
        height = 0.9,
        just = "top",
        y = 0.98
      )
      grid::pushViewport(margin_window)
      grid::grid.draw(table_grob)
      grid::popViewport()
    } else {
      # safer path (no layout conflict)
      grid::grid.draw(table_grob)
    }

    grDevices::dev.off()

  }

  message("File created: ", filepath)
  invisible(filepath)}

#' Make Normality Table
#'
#' Computes Shapiro-Wilk and Kolmogorov-Smirnov normality tests for specified variables.
#'
#' @param data A data frame.
#' @param vars Character vector of variable names. If NULL, all columns are used.
#' @importFrom stats shapiro.test ks.test
#' @return A data frame with W/D statistics and p-values for both tests.
#'
#' @export
make_normality_table <- function(data, vars = NULL) {

  if (is.null(vars)) vars <- names(data)
  df <- data[, vars, drop = FALSE]

  result <- do.call(rbind, lapply(vars, function(v) {
    x <- na.omit(df[[v]])

    sw <- shapiro.test(x)
    ks <- ks.test(x, "pnorm", mean = mean(x), sd = sd(x))


    format_p <- function(p) ifelse(p < .001, "< .001", as.character(round(p, 3)))

    data.frame(
      Variable  = v,
      SW_W      = round(sw$statistic, 3),
      SW_p = format_p(sw$p.value),
      KS_D      = round(ks$statistic, 3),
      KS_p = format_p(ks$p.value),
      stringsAsFactors = FALSE
    )
  }))

  rownames(result) <- NULL
  message("Note: p > .05 indicates data does not significantly deviate from normality. Shapiro-Wilk is generally recommended for small to moderate samples; interpret both tests alongside visual inspection (Q-Q plot, histogram).")
  return(result)
}

#' Check EFA Factorability and Return Summary Table
#'
#' This function calculates the overall Kaiser-Meyer-Olkin (KMO) MSA,
#' Bartlett's Test of Sphericity, and the Determinant of the correlation matrix.
#'
#' @param data A data frame containing the variables.
#' @param items A character vector of column names to be included in the analysis.
#' @param scale_name Character. A label for the scale (e.g., "GLPFS"). Defaults to "Overall".
#'
#' @return A data frame with one row containing the scale-level factorability diagnostics.
#'
#' @importFrom psych KMO cortest.bartlett
#' @export
make_EFA_factorability_table <- function(data, items, scale_name = "Overall") {

  if (!is.data.frame(data)) stop("Input 'data' must be a data frame.")

  # Ensure items exist in the data
  missing_items <- items[!items %in% colnames(data)]
  if (length(missing_items) > 0) {
    stop(paste("The following items were not found in the data:", paste(missing_items, collapse = ", ")))
  }

  # Subset data
  df_subset <- data[, items, drop = FALSE]

  # Correlation Matrix and Determinant
  cor_mat <- stats::cor(df_subset, use = "pairwise.complete.obs")


  # MODIFIED: Determinant formatting
  # Using 5 decimal places instead of scientific notation for readability
  det_val <- det(cor_mat)

  # KMO and Bartlett
  kmo_results <- psych::KMO(df_subset)
  bt_results <- psych::cortest.bartlett(df_subset)

  # Format P-Value Tier
  p_val <- bt_results$p.value
  p_tier <- ifelse(p_val < .001, "< .001",
                   ifelse(p_val < .01, "< .01",
                          ifelse(p_val < .05, "< .05",
                                 round(p_val, 3))))

  # Formatting results
  results <- data.frame(
    Scale          = scale_name,
    n_items        = length(items),
    KMO_Overall    = round(kmo_results$MSA, 3),
    Determinant    = format(det_val, scientific = TRUE, digits = 3),
    Bartlett_Chisq = round(bt_results$chisq, 2),
    df             = bt_results$df,
    p_value        = p_tier,
    stringsAsFactors = FALSE
  )

  # Check for Singularity/Multicollinearity
  if (det_val < 0.00001) {
    message("WARNING: Determinant is very low. Check for highly redundant items (r > 0.9).")
  }

  # Professional Warning
  message("Note: KMO and Bartlett's test only confirm factorability.")
  message("A high KMO_Overall can hide individual items with low MSAi.")
  message("Please inspect factor loadings and individual MSAi values for confirmation.")

  return(results)
}

#' Convert Between Alphabetical and Numeric Responses
#'
#' @description
#' Converts specified columns between alphabetical (text) and numeric values.
#' Can either overwrite existing columns or create new ones.
#'
#' @param data A data frame.
#' @param column_vars Character vector of column names to convert.
#' @param from_values Vector of values to replace (character or numeric).
#' @param to_values Vector of replacement values (must be same length as from_values).
#' @param new_names Optional character vector of new column names.
#'   If NULL (default), original columns are overwritten.
#' @param case_sensitive Logical. Only relevant when converting character values.
#'   Default is FALSE.
#'
#' @details
#' Factors are automatically converted to character before matching.
#' Unmatched values become NA with a warning.
#'
#' @return A data frame with converted values.
#' @export
make_alphanumeric_conversion <- function(data,
                                         column_vars,
                                         from_values,
                                         to_values,
                                         new_names = NULL,
                                         case_sensitive = FALSE) {

  # ---- Basic checks ----
  if (!is.data.frame(data)) {
    stop("data must be a data.frame")
  }

  if (!all(column_vars %in% names(data))) {
    missing <- setdiff(column_vars, names(data))
    stop("Columns not found in data: ", paste(missing, collapse = ", "))
  }

  if (length(from_values) != length(to_values)) {
    stop("from_values and to_values must be the same length")
  }

  if (!is.null(new_names) && length(new_names) != length(column_vars)) {
    stop("new_names must be same length as column_vars")
  }

  target_cols <- if (is.null(new_names)) column_vars else new_names

  # ---- Create mapping ----
  if (is.character(from_values) && !case_sensitive) {
    mapping <- stats::setNames(to_values, tolower(from_values))
  } else {
    mapping <- stats::setNames(to_values, from_values)
  }

  # ---- Apply conversion ----
  for (i in seq_along(column_vars)) {

    old_col <- column_vars[i]
    new_col <- target_cols[i]

    col_data <- data[[old_col]]

    # Convert factors to character
    if (is.factor(col_data)) {
      col_data <- as.character(col_data)
    }

    # Handle character matching
    if (is.character(from_values)) {

      if (!case_sensitive) {
        match_col <- tolower(as.character(col_data))
      } else {
        match_col <- as.character(col_data)
      }

      converted <- unname(mapping[match_col])

    } else {
      # Numeric matching
      converted <- unname(mapping[as.character(col_data)])
    }

    # ---- Unmatched warning ----
    original_na <- sum(is.na(col_data))
    new_na <- sum(is.na(converted))

    if (new_na > original_na) {
      unmatched <- setdiff(unique(col_data), from_values)
      unmatched <- unmatched[!is.na(unmatched)]
      if (length(unmatched) > 0) {
        warning("Column '", old_col, "' has unmatched values (becomes NA): ",
                paste(utils::head(unmatched, 5), collapse = ", "),
                if (length(unmatched) > 5) "..." else "")
      }
    }

    data[[new_col]] <- converted
  }

  return(data)
}

#' Compute Scale Total Score
#'
#' @description
#' Computes the total score for a psychometric scale by summing specified
#' numeric variables. The resulting total score is appended as a new column
#' to the input data frame. Missing values are handled using `na.rm = TRUE`.
#'
#' @param data A data frame.
#' @param vars A character vector of column names to be summed.
#' @param new_var A single character string specifying the name of the
#'   new total score column.
#'
#' @return The input data frame with one additional numeric column.
#' @export
make_scale_total <- function(data, vars, new_var) {

  # Validate data
  if (!is.data.frame(data)) {
    stop("`data` must be a data.frame.", call. = FALSE)
  }

  # Validate vars
  if (!is.character(vars) || length(vars) == 0) {
    stop("`vars` must be a non-empty character vector.", call. = FALSE)
  }

  missing_vars <- setdiff(vars, names(data))
  if (length(missing_vars) > 0) {
    stop(
      paste("Variables not found in data:",
            paste(missing_vars, collapse = ", ")),
      call. = FALSE
    )
  }

  # Validate new_name
  if (!is.character(new_var) || length(new_var) != 1) {
    stop("`new_var` must be a single character string.", call. = FALSE)
  }

  if (new_var %in% names(data)) {
    stop(
      paste("Column", new_var, "already exists in data."),
      call. = FALSE
    )
  }

  # Subset and check numeric
  sub_data <- data[, vars, drop = FALSE]

  non_numeric <- names(sub_data)[!vapply(sub_data, is.numeric, logical(1))]
  if (length(non_numeric) > 0) {
    stop(
      paste("Non-numeric variables detected:",
            paste(non_numeric, collapse = ", ")),
      call. = FALSE
    )
  }

  # Compute total
  data[[new_var]] <- rowSums(sub_data, na.rm = TRUE)

  data
}

#' Create a one-row summary table for an independent-samples t-test
#'
#' This function performs an independent-samples t-test (Welch's t-test by default)
#' between two groups defined by a binary grouping variable and returns a
#' single-row data frame. The output includes group names,
#' sample sizes, mean difference, test statistics, p-value, and effect size
#' (Cohen's d) with a qualitative interpretation.
#'
#' The function is intended for streamlined reporting and does not introduce
#' new statistical methods. All computations rely on \code{stats::t.test()}.
#'
#' @param data A data frame containing the outcome and grouping variables.
#' @param outcome Character string specifying the numeric outcome variable.
#' @param group Character string specifying the grouping variable. Must have exactly two levels.
#'
#' @return A single-row data frame with the following columns:
#' \itemize{
#'   \item \code{test}: Name of the statistical test
#'   \item \code{group1}, \code{group2}: Group labels
#'   \item \code{mean_diff}: Mean difference between groups (group1 - group2)
#'   \item \code{t_value}: t statistic
#'   \item \code{df}: Degrees of freedom
#'   \item \code{p_value}: p-value
#'   \item \code{n_group1}, \code{n_group2}: Sample sizes per group
#'   \item \code{cohens_d}: Cohen's d effect size
#'   \item \code{interpretation}: Qualitative interpretation of effect size
#' }
#'
#' @details
#' Welch’s t-test is used by default, which does not assume equal variances.
#' Cohen’s d is computed using the pooled standard deviation for comparability
#' with conventional benchmarks. Group ordering follows the factor level order
#' of the grouping variable.
#'
#' @examples
#' set.seed(123)
#'
#' data_t <- data.frame(
#'   group = rep(c("CBT", "Psychodynamic"), each = 30),
#'   score = c(
#'     rnorm(30, mean = 18, sd = 4),
#'     rnorm(30, mean = 21, sd = 4)
#'   )
#' )
#'
#' make_independent_t_test_table(
#'   data = data_t,
#'   outcome = "score",
#'   group = "group"
#' )
#' @importFrom stats sd
#' @export
make_independent_t_test_table <- function(data, outcome, group) {
  # Extract variables
  y <- data[[outcome]]
  g <- data[[group]]

  if (length(unique(g)) != 2) {
    stop("Grouping variable must have exactly two levels")
  }

  # Run Welch t-test
  t_obj <- t.test(y ~ g)

  # Group stats
  grp <- split(y, g)
  m1 <- mean(grp[[1]], na.rm = TRUE)
  m2 <- mean(grp[[2]], na.rm = TRUE)
  s1 <- sd(grp[[1]], na.rm = TRUE)
  s2 <- sd(grp[[2]], na.rm = TRUE)
  n1 <- length(grp[[1]])
  n2 <- length(grp[[2]])

  # Pooled SD
  sd_pooled <- sqrt(
    ((n1 - 1) * s1^2 + (n2 - 1) * s2^2) /
      (n1 + n2 - 2)
  )

  # Cohen's d
  d <- (m1 - m2) / sd_pooled

  interpretation <- cut(
    abs(d),
    breaks = c(-Inf, 0.2, 0.5, 0.8, Inf),
    labels = c("Negligible", "Small", "Medium", "Large")
  )

  data.frame(
    test = "Independent t-test",
    group1 = names(grp)[1],
    group2 = names(grp)[2],
    mean_diff = round(m1 - m2, 3),
    t_value = round(unname(t_obj$statistic), 3),
    df = round(unname(t_obj$parameter), 2),
    p_value = t_obj$p.value,
    n_group1 = n1,
    n_group2 = n2,
    cohens_d = round(d, 3),
    interpretation = as.character(interpretation),
    stringsAsFactors = FALSE
  )
}

#' scaledescr
#'
#' Provides helper functions to format and summarise already computed outputs from commonly used statistical and psychometric functions into compact, single-row tables and simple graphs. Functions such as make_scale_description_table(), make_demographic_table(), make_alpha_table(), make_paired_t_test_table(), and make_dataframe_to_output() organise results obtained from existing functions including psych::describe(), psych::alpha(), stats::t.test(), and gtsummary::tbl_summary() for streamlined reporting and export to CSV, Word, and Excel formats. The package does not implement new statistical methods or perform additional estimation.
#'
#' @name scaledescr
NULL

#' Compute Intraclass Correlation Coefficient (ICC) for Selected Columns
#'
#' @description
#' Computes Intraclass Correlation Coefficients (ICC) for a specified set
#' of numeric variables within a data frame using \code{psych::ICC()}.
#'
#' This function standardizes column selection and basic validation while
#' delegating all statistical estimation to \code{psych::ICC()}.
#'
#' @param data A data frame containing the ratings or measurements.
#' @param items A character vector specifying column names for which
#'   ICC should be calculated (e.g., raters or repeated measurements).
#' @param check_numeric Logical. If \code{TRUE} (default), ensures all
#'   selected columns are numeric.
#' @param lmer Logical. Passed to \code{psych::ICC()}. Default is FALSE.
#' @param ... Additional arguments passed to \code{psych::ICC()}.
#'
#' @return An object returned by \code{psych::ICC()}, typically a list
#'   containing a results table with ICC estimates, F statistics,
#'   confidence intervals, and model details.
#'
#' @details
#' The function does not choose or filter specific ICC models.
#' All available ICC types (e.g., ICC1, ICC2, ICC3, single and average)
#' are returned exactly as produced by \code{psych::ICC()}.
#'
#' Users are responsible for:
#' \itemize{
#'   \item Choosing the appropriate ICC model for their study design.
#'   \item Ensuring assumptions (e.g., continuous ratings, independence).
#'   \item Handling missing data appropriately.
#' }
#' @seealso
#' \code{\link[psych]{ICC}}
#'
#' @importFrom psych ICC
#' @export
compute_ICC <- function(data,
                        items,
                        check_numeric = TRUE,
                        lmer = FALSE,
                        ...) {

  # ---- Validate data ----
  if (!is.data.frame(data)) {
    stop("`data` must be a data frame.")
  }

  if (missing(items) || length(items) < 2) {
    stop("`items` must contain at least two column names.")
  }

  if (!all(items %in% names(data))) {
    missing_items <- items[!items %in% names(data)]
    stop(
      paste("The following items were not found in `data`:",
            paste(missing_items, collapse = ", "))
    )
  }

  # ---- Subset data ----
  sub_data <- data[, items, drop = FALSE]

  # ---- Numeric check ----
  if (check_numeric) {
    non_numeric <- names(sub_data)[!sapply(sub_data, is.numeric)]
    if (length(non_numeric) > 0) {
      stop(
        paste("The following items are not numeric:",
              paste(non_numeric, collapse = ", "))
      )
    }
  }

  # ---- Compute ICC using psych ----
  psych::ICC(sub_data, lmer = lmer, ...)
}

#' Create a Summary Table for a One-Sample t-test
#'
#' @param t_res An object of class "htest" produced by \code{t.test()},or a list of such objects.
#' @param variable_label A character string to label the tested variable(s).
#' @param digits Integer indicating the number of decimal places to round to.
#'
#' @return A data frame summarizing the one-sample t-test results.
#'
#' @examples
#' data("attitude")
#' A <- as.data.frame(attitude)
#'
#' # Example 1: One-sample t-test with default mu = 0
#' t1 <- t.test(A$rating)
#' make_one_sample_t_test_table(
#'   t_res = t1,
#'   variable_label = "Rating"
#' )
#'
#' # Example 2: One-sample t-test with specified mu
#' t2 <- t.test(A$rating, mu = 60)
#' make_one_sample_t_test_table(
#'   t_res = t2,
#'   variable_label = "Rating"
#' )
#'
#' # Example 3: Multiple one-sample t-tests combined into one table
#' t1 <- t.test(A$rating)
#' t2 <- t.test(A$learning)
#' t3 <- t.test(A$raises)
#'
#' make_one_sample_t_test_table(
#'   t_res = list(t1, t2, t3),
#'   variable_label = c("Rating", "Learning", "Raises")
#' )
#'
#' # Example 4: Multiple tests with different mu values
#' t1 <- t.test(A$rating, mu = 60)
#' t2 <- t.test(A$learning, mu = 65)
#' t3 <- t.test(A$raises, mu = 50)
#'
#' make_one_sample_t_test_table(
#'   t_res = list(t1, t2, t3),
#'   variable_label = c("Rating", "Learning", "Raises (mu = 50)")
#' )
#' @export
make_one_sample_t_test_table <- function(t_res, variable_label = "Variable", digits = 3) {

  # 1 Allow single htest or list of htest
  if(inherits(t_res,"htest")){
    t_res <- list(t_res)
  }

  # 2. Validate the input
  if (!all(sapply(t_res,inherits,"htest" ))) {
    stop("All inputs must be an 'htest' object generated by t.test()")
  }

  # 3. the label are equal number as htest object
  n_tests <- length(t_res)

  if (length(variable_label) == 1) {
    variable_label <- rep(variable_label, n_tests)
  }

  if (length(variable_label) != n_tests) {
    stop("Length of variable_label must match number of tests")
  }

   # 4. Extract and format the statistics into a data frame
  results <- lapply(seq_along(t_res), function(i) {

    test <- t_res[[i]]

    # format p value

    p_formatted <- ifelse(test$p.value < 10^-digits,
                          paste0("< ", formatC(10^-digits, format = "f", digits = digits)),
                          formatC(test$p.value, format = "f", digits = digits))
    data.frame(
      Variable = variable_label[i],
      Sample_Mean = round(as.numeric(test$estimate), digits),
      Test_Value = round(as.numeric(test$null.value), digits),
      t_statistic = round(as.numeric(test$statistic), digits),
      df = as.numeric(test$parameter),
      p_value = p_formatted,
      CI_lower = round(as.numeric(test$conf.int[1]), digits),
      CI_upper = round(as.numeric(test$conf.int[2]), digits),
      stringsAsFactors = FALSE
    )
  })

  # bind all result in a table
  df <- do.call(rbind, results)
  rownames(df) <- NULL

  return(df)
}

#' Create a one-row summary table for a chi-square test
#'
#' This function formats the result of a pre-computed \code{chisq.test()}
#' into a single-row data frame. It supports goodness-of-fit,
#' independence, and homogeneity chi-square tests and includes an appropriate
#' effect size with a qualitative interpretation.
#'
#' The function does not perform the chi-square test itself and does not
#' introduce new statistical methods. All test statistics are extracted
#' directly from the supplied \code{chisq.test()} object.
#'
#' @param chisq_object An object or list of objects of class \code{"htest"} produced by
#'   \code{stats::chisq.test()}.
#' @param test_type Character string specifying the type of chi-square test.
#'   One of \code{"goodness-of-fit"}, \code{"independence"}, or
#'   \code{"homogeneity"}.  for multiple object, if separate test_type are not provided than given test type will be uesd for all chi square test./
#' @param digits Integer indicating the number of decimal places to round to.
#'
#' @return A single-row data frame with the following columns:
#' \itemize{
#'   \item \code{test}: Type of chi-square test
#'   \item \code{chi_square}: Chi-square statistic
#'   \item \code{df}: Degrees of freedom
#'   \item \code{p_value}: p-value
#'   \item \code{N}: Total sample size
#'   \item \code{effect_size}: Effect size (Cohen’s w or Cramér’s V)
#'   \item \code{effect_type}: Type of effect size reported
#'   \item \code{effect_interpretation}: Qualitative interpretation of effect size
#' }
#'
#' @details
#' For goodness-of-fit tests, Cohen’s w is reported. For tests of independence
#' and homogeneity, Cramér’s V is reported. Effect size interpretations follow
#' conventional benchmarks (0.10 = small, 0.30 = medium, 0.50 = large).
#'
#' @examples
#' # Goodness-of-fit example
#' observed <- c(40, 30, 50)
#' chisq_gof <- chisq.test(observed)
#'
#' make_chisq_test_table(
#'   chisq_object = chisq_gof,
#'   test_type = "goodness-of-fit"
#' )
#'
#' # Independence test example
#' tbl <- matrix(c(20, 30, 10, 40), nrow = 2)
#' chisq_ind <- chisq.test(tbl)
#'
#' make_chisq_test_table(
#'   chisq_object = chisq_ind,
#'   test_type = "independence"
#' )
#'
#' @export
make_chisq_test_table <- function(
    chisq_object,
    test_type = c("independence", "goodness-of-fit", "homogeneity"),
    digits = 3
) {

  # 1. Allow single htest or list of htest
  if (inherits(chisq_object, "htest")) {
    chisq_object <- list(chisq_object)
  }

  # 2. Validate the input
  if (!all(sapply(chisq_object, inherits, "htest"))) {
    stop("All inputs must be a chisq.test() result object.")
  }

  # 3. Handle test_type argument logic
  valid_types <- c("independence", "goodness-of-fit", "homogeneity")

  # If user didn't change the default or provided nothing
  if (missing(test_type) || identical(test_type, valid_types)) {
    test_type <- "independence"
  }

  # 4. Recycle test_type if it's only length 1 to match number of tests
  if (length(test_type) == 1) {
    test_type <- rep(test_type, length(chisq_object))
  }

  # 5. Check and Standardize types (This replaces match.arg for vector support)
  test_type <- sapply(test_type, function(x) {
    if (x %in% valid_types) {
      return(x)
    } else {
      warning(paste0("'", x, "' is not a standard type. Defaulting to 'independence'."))
      return("independence")
    }
  })

  # 6. Process each test
  results <- lapply(seq_along(chisq_object), function(i) {
    obj <- chisq_object[[i]]
    type <- test_type[i]

    chi_sq <- unname(obj$statistic)
    df <- unname(obj$parameter)
    p_val <- obj$p.value
    N <- sum(obj$observed)

    # Effect Size Logic
    if (type == "goodness-of-fit") {
      effect_type <- "Cohen_w"
      effect_size <- sqrt(chi_sq / N)
    } else {
      effect_type <- "Cramers_V"
      dims <- dim(obj$observed)
      # k is min(rows, cols) - 1. For vectors, dims is NULL, so k=1.
      k <- if (is.null(dims)) 1 else min(dims) - 1
      k <- ifelse(k < 1, 1, k)
      effect_size <- sqrt(chi_sq / (N * k))
    }

    # Interpretation (Cohen, 1988)
    #
    effect_label <- ifelse(effect_size < 0.10, "negligible",
                           ifelse(effect_size < 0.30, "small",
                                  ifelse(effect_size < 0.50, "medium", "large")))

    # Format p-value
    p_formatted <- ifelse(p_val < 10^-digits,
                          paste0("< ", formatC(10^-digits, format = "f", digits = digits)),
                          formatC(p_val, format = "f", digits = digits))

    data.frame(
      test = type,
      chi_square = round(chi_sq, digits),
      df = df,
      p_value = p_formatted,
      N = N,
      effect_size = round(effect_size, digits),
      effect_type = effect_type,
      effect_interpretation = effect_label,
      stringsAsFactors = FALSE
    )
  })

  # 7. Bind into one table
  df_final <- do.call(rbind, results)
  rownames(df_final) <- NULL
  return(df_final)
}

#' Make Correlation Table
#'
#' Computes a correlation matrix with inline significance stars.
#'
#' @param data A data frame.
#' @param vars Character vector of variable names. If NULL, all columns are used.
#' @param method Correlation method: "pearson" (default), "spearman", or "kendall".
#' @importFrom stats cor.test
#' @return A character data frame with correlations and significance stars.
#' @export
make_correlation_table <- function(data, vars = NULL, method = "pearson") {

  if (is.null(vars)) vars <- names(data)
  df <- data[, vars, drop = FALSE]

  n <- ncol(df)
  cor_mat <- matrix(NA_character_, nrow = n, ncol = n)
  rownames(cor_mat) <- vars
  colnames(cor_mat) <- vars

  for (i in seq_len(n)) {
    for (j in seq_len(n)) {
      if (i == j) {
        cor_mat[i, j] <- "1.00"
      } else {
        test <- cor.test(df[[i]], df[[j]], method = method, exact = FALSE)
        r <- sprintf("%.2f", test$estimate)
        p <- test$p.value
        stars <- ifelse(p < .001, "***",
                        ifelse(p < .01,  "**",
                               ifelse(p < .05,  "*", "")))
        cor_mat[i, j] <- paste0(r, stars)
      }
    }
  }

  result <- as.data.frame(cor_mat, stringsAsFactors = FALSE)
  attr(result, "method") <- method
  attr(result, "note")   <- "* p<.05  ** p<.01  *** p<.001"
  message("Note: * p<.05  ** p<.01  *** p<.001  (method: ", method, ")")
  return(result)
}

#' Comprehensive Lavaan Regression Analysis
#'
#' @description Fits a lavaan model and returns a list containing the regression
#' coefficients table and the global model fit indices.
#'
#' @param data A dataframe.
#' @param dvs A character vector of one or more Dependent Variables.
#' @param ivs A character vector of one or more Independent Variables.
#' @param standardize Logical. If TRUE, standardizes data before analysis.
#' @importFrom lavaan sem parameterEstimates standardizedSolution fitMeasures lavInspect
#' @return A list with two dataframes: 'Regression' and 'Fit'.
#' @export
make_lavaan_analysis_tables <- function(data, dvs, ivs, standardize = FALSE) {

  # 1. PREP & FIT
  data_sub <- data[, c(dvs, ivs)]
  if(standardize) {
    data_sub <- as.data.frame(lapply(data_sub, scale))
  }

  formula_string <- paste(paste(dvs, collapse = " + "), "~", paste(ivs, collapse = " + "))
  fit <- lavaan::sem(formula_string, data = data_sub, fixed.x = FALSE, missing = "fiml")

  # 2. BUILD REGRESSION DATAFRAME
  est <- lavaan::parameterEstimates(fit)
  std <- lavaan::standardizedSolution(fit)
  reg_df <- est[est$op == "~", c("lhs", "rhs", "est", "se", "z", "pvalue")]
  reg_df$Beta <- std$est.std[std$op == "~"]

  colnames(reg_df) <- c("Outcome", "Predictor", "B", "SE", "z", "p", "Beta")
  reg_df$p <- ifelse(reg_df$p < .001, "<.001", sprintf("%.3f", reg_df$p))
  num_cols <- c("B", "SE", "z", "Beta")
  reg_df[num_cols] <- lapply(reg_df[num_cols], round, 3)
  rownames(reg_df) <- NULL

  # 3. BUILD FIT DATAFRAME
  indices <- lavaan::fitMeasures(fit, c("cfi", "tli", "rmsea", "srmr"))
  fit_df <- data.frame(
    Index = c("CFI", "TLI", "RMSEA", "SRMR"),
    Value = round(as.numeric(indices), 3),
    Threshold = c("> 0.90", "> 0.90", "< 0.08", "< 0.08")
  )

  # 4. EXTRACT R-SQUARED
  r2_vals <- round(lavaan::lavInspect(fit, "rsquare"), 3)

  # --- CONSOLE PRINTING ---
  cat("\n==============================\n")
  cat("  LAVAAN REGRESSION RESULTS   \n")
  cat("==============================\n")
  print(reg_df)

  cat("\n--- Model R-Squared ---\n")
  print(r2_vals)

  cat("\n--- Global Model Fit ---\n")
  print(fit_df)

  # --- ACCESS NOTE ---
  cat("\n------------------------------------------------------------\n")
  cat("NOTE: To access these tables later, save the output to a variable\n")
  cat("Example: res <- make_lavaan_analysis_tables(...)\n")
  cat("Then use:\n")
  cat(" - res$Regression  : For the coefficients table\n")
  cat(" - res$Fit         : For the model fit indices\n")
  cat(" - res$R2          : For the R-squared values\n")
  cat("------------------------------------------------------------\n")

  # Return everything in a clean list
  return(invisible(list(Regression = reg_df, Fit = fit_df, R2 = r2_vals)))
}

#' Create a one-row summary table of a paired t-test
#'
#' This function performs a paired t-test between two numeric variables in a data frame
#' and returns a one-row summary table including means, mean difference, t-value, degrees of freedom,
#' p-value, and confidence interval.
#'
#' @param data A data frame containing the two numeric variables.
#' @param var1 Character string. Name of the first variable (observation 1) in `data`.
#' @param var2 Character string. Name of the second variable (observation 2) in `data`.
#' @param var_name Optional character string. Custom name for the variable to display in the table. Default is `var1 vs var2`.
#' @param alternative Character string specifying the alternative hypothesis. One of `"two.sided"`, `"less"`, or `"greater"`. Default is `"two.sided"`.
#' @param conf.level Confidence level for the interval. Default is 0.95.
#'
#' @return A one-row data frame with columns:
#' \itemize{
#'   \item `Variable` - variable name
#'   \item `Mean_obs1` - mean of observation 1
#'   \item `Mean_obs2` - mean of observation 2
#'   \item `Mean_diff` - mean difference (obs1 - obs2)
#'   \item `t_value` - t statistic
#'   \item `df` - degrees of freedom
#'   \item `p_value` - p-value
#'   \item `CI_lower` - lower bound of confidence interval
#'   \item `CI_upper` - upper bound of confidence interval
#' }
#'
#' @export
#' @examples
#' # example data
#' df <- data.frame(
#'   before = c(10, 12, 14, 15, 11),
#'   after  = c(11, 13, 13, 16, 12)
#' )
#'
#' # Run the paired t-test summary
#' make_paired_t_test_table(df, var1 = "before", var2 = "after")

#' @importFrom stats t.test na.omit
make_paired_t_test_table <- function(data, var1, var2, var_name = NULL,
                                     alternative = "two.sided", conf.level = 0.95) {
  # extract variables
  x <- data[[var1]]
  y <- data[[var2]]

  # keep complete pairs only
  paired_data <- na.omit(data.frame(x, y))

  # paired t-test
  tt <- t.test(paired_data$x,
    paired_data$y,
    paired = TRUE,
    alternative = alternative,
    conf.level = conf.level
  )

  # means
  mean_x <- mean(paired_data$x)
  mean_y <- mean(paired_data$y)

  # variable label
  if (is.null(var_name)) {
    var_name <- paste(var1, "vs", var2)
  }

  # result table
  data.frame(
    Variable      = var_name,
    Mean_obs1     = round(mean_x, 2),
    Mean_obs2     = round(mean_y, 2),
    Mean_diff     = round(as.numeric(tt$estimate), 2),
    t_value       = round(as.numeric(tt$statistic), 2),
    df            = as.numeric(tt$parameter),
    p_value       = round(tt$p.value, 3),
    CI_lower      = round(tt$conf.int[1], 2),
    CI_upper      = round(tt$conf.int[2], 2)
  )
}

#' Create Descriptive Table for Multiple Scale Columns
#'
#' Computes descriptive statistics for one or more scale total columns.
#' Accepts either a numeric vector (single column) or a data frame with column names.
#'
#' @param x Optional numeric vector of total scores (single column, old-style).
#' @param data Optional data frame containing one or more scale columns.
#' @param columns Optional character vector of column names in `data` (new-style).
#' @param scale_names Optional character vector of names for each scale. Defaults to column names.
#' @param type "summary" for base::summary(), NULL (default) uses psych::describe().
#'
#' @return A data frame with one row per column, containing descriptive statistics.
#' @export
make_scale_description_table <- function(x = NULL, data = NULL, columns = NULL,
                                         scale_names = NULL, type = NULL) {

  # ---- Determine input ----
  if (!is.null(data)) {
    if (!is.data.frame(data)) stop("data must be a data.frame")
    if (is.null(columns)) stop("columns must be provided when using data")
    missing_cols <- setdiff(columns, names(data))
    if (length(missing_cols) > 0) stop("Columns not found in data: ", paste(missing_cols, collapse = ", "))
    x_list <- lapply(columns, function(col) data[[col]])
  } else if (!is.null(x)) {
    # single numeric vector
    if (!is.numeric(x)) stop("x must be numeric")
    x_list <- list(x)
    if (is.null(scale_names)) scale_names <- "Scale1"
  } else {
    stop("Either x or data must be provided")
  }

  # ---- Scale names ----
  if (!is.null(data)) {
    if (is.null(scale_names)) scale_names <- columns
    if (length(scale_names) != length(columns)) stop("scale_names length must match columns length")
  }

  # ---- Compute statistics for each column ----
  results <- lapply(seq_along(x_list), function(i) {
    x_col <- x_list[[i]]
    scale_name <- scale_names[i]

    if (is.null(type)) {
      descr <- psych::describe(x_col)
      data.frame(
        Scale = scale_name,
        N = descr$n,
        Mean = round(descr$mean, 2),
        SD = round(descr$sd, 2),
        Median = round(descr$median, 2),
        Range = paste0(round(descr$min, 2), "-", round(descr$max, 2)),
        Skewness = round(descr$skew, 2),
        Kurtosis = round(descr$kurtosis, 2),
        stringsAsFactors = FALSE
      )
    } else if (type == "summary") {
      s <- summary(x_col)
      data.frame(
        Scale = scale_name,
        N = sum(!is.na(x_col)),
        `1st Qu.` = round(s[["1st Qu."]], 2),
        Median = round(s[["Median"]], 2),
        Mean = round(s[["Mean"]], 2),
        `3rd Qu.` = round(s[["3rd Qu."]], 2),
        Range = paste0(round(s[["Min."]], 2), "-", round(s[["Max."]], 2)),
        stringsAsFactors = FALSE
      )
    } else {
      stop("type must be NULL or 'summary'")
    }
  })

  # ---- Combine into one table ----
  do.call(rbind, results)
}

#' Wrap a pre computed psych::alpha object into a single row table with N and alpha only.
#'
#' Extracts only the Scale Name, Sample Size (N), and Cronbach's Alpha
#' from a `psych::alpha` object.
#' @param alpha_res A psych::alpha object (already computed)
#' @param scale_name Name of the scale (default: "Scale")
#'
#' @return A data frame with three columns: Scale,N, and Alpha.
#' @examples
#' \dontrun{
#' library(psych)
#' res <- psych::alpha(mtcars[,1:3])
#' make_alpha_table(res, scale_name = "Car Scale")
#' }
#' @export
make_alpha_table <- function(alpha_res, scale_name = "Scale") {

  # 1. Provide the requested warning about the structural change
  warning("The current version simplify output to Scale, N, and Alpha.
           The previous version of  `make_alpha_table()` was returning inconsistent results for
          some psych::alpha objects due to variation in alpha_res object structure.")

  # 2. Initialize variables to NA to satisfy CMD check and handle missing data
  raw_alpha <- NA
  n_obs <- NA

  # 3. Robust extraction of required values
  # Alpha: from total summary, rounded to 2 decimals
  raw_alpha <- if (!is.null(alpha_res$total$raw_alpha)) {
    round(as.numeric(alpha_res$total$raw_alpha), 2)
  } else {
    NA
  }

  # 4. Create the simplified table
  # Using stringsAsFactors = FALSE is best practice for older R versions
  res_df <- data.frame(
    Scale = scale_name,
    N = n_obs,
    Alpha = raw_alpha,
    stringsAsFactors = FALSE,
    check.names = FALSE
  )
  return(res_df)
}

#' Create a demographics summary table
#'
#' @param data A data frame
#' @param vars demographic variables to include in the table
#' @param continuous_vars Optional subset of vars to be treated as continuous
#'
#' @return A gtsummary table
#' @export
#' @examples
#' df <- data.frame(
#'   age = c("25", "30 years", "35", " 40 ", "22.5", "28+", NA, ""),
#'   sex = c("M", "F", "m", "f", " M ", "F", "m", NA),
#'   education = c("HS", "BA", "MA", "ma", "Hs", "Ma", "Ba Bed", "Msc bed ")
#' )
#'
#' # Generate a demographic summary table (assign to object to avoid printing)
#' demo_table <- make_demographic_table(df, vars = c("age", "sex", "education"))
#' demo_table # optionally inspect the table
#'
#' @importFrom dplyr select all_of
#' @importFrom dplyr %>%
#' @importFrom gtsummary tbl_summary all_categorical all_continuous
#' @importFrom purrr map_lgl map_chr
#' @importFrom rlang enquos as_name
#' @importFrom stringr str_trim str_to_title
make_demographic_table <- function(data, vars, continuous_vars = NULL) {

  # --- Check vars exist ---
  if (!all(vars %in% names(data))) {
    stop("Some variables in `vars` are not present in `data`.",
         call. = FALSE)
  }

  # --- Check continuous_vars only if provided ---
  if (!is.null(continuous_vars)) {
    if (!all(continuous_vars %in% vars)) {
      stop("All continuous_vars must also be included in vars.",
           call. = FALSE)
    }
  }

  data_selected <- data |>
    dplyr::select(dplyr::all_of(vars)) |>
    dplyr::mutate(
      dplyr::across(
        dplyr::where(is.character),
        ~ {res <- stringr::str_to_title(stringr::str_trim(.))
        ifelse(res == "", NA_character_, res)
        }
      )
    )

  # --- Detect or assign continuous variables ---
  if (is.null(continuous_vars)) {
    continuous_names <- names(data_selected)[
      purrr::map_lgl(data_selected, is.numeric)
    ]
  } else {
    # User-specified continuous variables
    continuous_names <- continuous_vars

    # Coerce even if alphabets are present
    data_selected <- data_selected |>
      dplyr::mutate(
        dplyr::across(
          dplyr::all_of(continuous_names),
          ~ suppressWarnings(
            as.numeric(gsub("[^0-9.+-]", "", as.character(.)))
          )
        )
      )
  }

  # --- Define type list safely ---
  type_list <- NULL
  if (length(continuous_names) > 0) {
    type_list <- list(dplyr::all_of(continuous_names) ~ "continuous")
  }

  gtsummary::tbl_summary(
    data_selected,
    statistic = list(
      gtsummary::all_categorical() ~ "{n} ({p}%)",
      gtsummary::all_continuous() ~ "{mean} ({sd})"
    ),
    type = type_list,
    missing = "ifany"
  )
}

#' Create and Export Demographic Summary Table
#'
#' @description
#' Generates a demographic summary table using `make_demographic_table()`
#' and exports the resulting table to Word, Excel, or CSV format.
#'
#' This is a convenience wrapper that combines analysis and output
#' in a single step for users who want immediate file export.
#'
#' @param data A data frame containing the dataset.
#' @param vars Character vector of variable names to include in the
#'   demographic summary.
#' @param continuous_vars Optional character vector specifying which
#'   variables should be treated as continuous.
#'   If `NULL`, numeric variables are automatically detected.
#' @param file_name Name of the output file WITHOUT extension
#'   (e.g., "demographics").
#' @param format Output format. Must be one of:
#'   \itemize{
#'     \item `"word"`  - exports to a Word document (.docx)
#'     \item `"excel"` - exports to an Excel file (.xlsx)
#'     \item `"csv"`   - exports to a CSV file (.csv)
#'   }
#' @param path Optional character string specifying the directory where the
#'   file should be saved. If `NULL` (default), the file is written to a
#'   temporary directory. Provide a full directory path or use getwd()
#'   during the function call.
#'
#' @details
#' The demographic table includes:
#' \itemize{
#'   \item Categorical variables reported as n (%)
#'   \item Continuous variables reported as Mean (SD)
#' }
#'
#' Word export uses `flextable` and `officer` for formatting.
#' Excel export uses `openxlsx`.
#' CSV export uses base R `write.csv()`.
#'
#' @return Invisibly returns the full file path to the generated output file.
#'
#' @export
make_demographic_table_to_output <- function(data,
                                             vars,
                                             continuous_vars = NULL,
                                             file_name = "demographic_table",
                                             format = c("word", "excel", "csv"),
                                             path = NULL) {

  format <- match.arg(format)

  # 1. Determine output directory
  if (is.null(path)) {
    out_dir <- tempdir()
  } else {
    out_dir <- path
  }

  if (!dir.exists(out_dir)) stop("Directory does not exist: ", out_dir, call. = FALSE)

  # 2. Construct full file path FIRST
  ext <- switch(format,
                "word" = "docx",
                "excel" = "xlsx",
                "csv" = "csv")

  filepath <- file.path(out_dir, paste0(file_name, ".", ext))

  # 3. Generate demographic table and convert to dataframe
  gtsummary_table <- make_demographic_table(
    data = data,
    vars = vars,
    continuous_vars = continuous_vars
  )

  table_data <- as.data.frame(gtsummary_table)

  # 4. Export the dataframe using the constructed 'filepath'
  if (format == "word") {
    if (!requireNamespace("flextable", quietly = TRUE)) {
      stop("Package 'flextable' is required for Word export. Please install it.")
    }
    if (!requireNamespace("officer", quietly = TRUE)) {
      stop("Package 'officer' is required for Word export. Please install it.")
    }

    flex_tbl <- flextable::flextable(table_data)
    flex_tbl <- flextable::autofit(flex_tbl)
    doc <- officer::read_docx()
    doc <- flextable::body_add_flextable(doc, flex_tbl)
    print(doc, target = filepath)
  }

  if (format == "excel") {
    if (!requireNamespace("openxlsx", quietly = TRUE)) {
      stop("Package 'openxlsx' is required for Excel export. Please install it.")
    }
    openxlsx::write.xlsx(table_data, file = filepath)
  }

  if (format == "csv") {
    utils::write.csv(table_data, file = filepath, row.names = FALSE)
  }

  message("File created: ", filepath)
  invisible(filepath)
}

#' Create Reverse Scores as New Columns
#'
#' @param data A data frame.
#' @param vars A character vector of column names to reverse.
#' @param min_val The minimum possible score of the scale.
#' @param max_val The maximum possible score of the scale.
#' @param suffix A character string to append to the new column names. Defaults to "_rev".
#'
#' @return A data frame containing the original data plus the new reversed columns.
#' @export
make_reverse_score <- function(data, vars, min_val, max_val, suffix = "_rev") {

  # Warn if multiple variables are supplied
  if (length(vars) > 1) {
    warning("Multiple variables selected for reverse scoring. Ensure that min_val and max_val are identical for all variables.")
  }

  # Calculate the reversal constant
  rev_constant <- min_val + max_val

  # Generate the new column names (e.g., "Q1_rev")
  new_cols <- paste0(vars, suffix)

  # Calculate reverse scores and assign them directly to the new columns
  data[new_cols] <- rev_constant - data[vars]

  return(data)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_chisq_test_table.R
\name{make_chisq_test_table}
\alias{make_chisq_test_table}
\title{Create a one-row summary table for a chi-square test}
\usage{
make_chisq_test_table(
  chisq_object,
  test_type = c("independence", "goodness-of-fit", "homogeneity"),
  digits = 3
)
}
\arguments{
\item{chisq_object}{An object or list of objects of class \code{"htest"} produced by
\code{stats::chisq.test()}.}

\item{test_type}{Character string specifying the type of chi-square test.
One of \code{"goodness-of-fit"}, \code{"independence"}, or
\code{"homogeneity"}.  for multiple object, if separate test_type are not provided than given test type will be uesd for all chi square test./}

\item{digits}{Integer indicating the number of decimal places to round to.}
}
\value{
A single-row data frame with the following columns:
\itemize{
  \item \code{test}: Type of chi-square test
  \item \code{chi_square}: Chi-square statistic
  \item \code{df}: Degrees of freedom
  \item \code{p_value}: p-value
  \item \code{N}: Total sample size
  \item \code{effect_size}: Effect size (Cohen’s w or Cramér’s V)
  \item \code{effect_type}: Type of effect size reported
  \item \code{effect_interpretation}: Qualitative interpretation of effect size
}
}
\description{
This function formats the result of a pre-computed \code{chisq.test()}
into a single-row data frame. It supports goodness-of-fit,
independence, and homogeneity chi-square tests and includes an appropriate
effect size with a qualitative interpretation.
}
\details{
The function does not perform the chi-square test itself and does not
introduce new statistical methods. All test statistics are extracted
directly from the supplied \code{chisq.test()} object.


For goodness-of-fit tests, Cohen’s w is reported. For tests of independence
and homogeneity, Cramér’s V is reported. Effect size interpretations follow
conventional benchmarks (0.10 = small, 0.30 = medium, 0.50 = large).
}
\examples{
# Goodness-of-fit example
observed <- c(40, 30, 50)
chisq_gof <- chisq.test(observed)

make_chisq_test_table(
  chisq_object = chisq_gof,
  test_type = "goodness-of-fit"
)

# Independence test example
tbl <- matrix(c(20, 30, 10, 40), nrow = 2)
chisq_ind <- chisq.test(tbl)

make_chisq_test_table(
  chisq_object = chisq_ind,
  test_type = "independence"
)

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_paired_t_test_table.R
\name{make_paired_t_test_table}
\alias{make_paired_t_test_table}
\title{Create a one-row summary table of a paired t-test}
\usage{
make_paired_t_test_table(
  data,
  var1,
  var2,
  var_name = NULL,
  alternative = "two.sided",
  conf.level = 0.95
)
}
\arguments{
\item{data}{A data frame containing the two numeric variables.}

\item{var1}{Character string. Name of the first variable (observation 1) in `data`.}

\item{var2}{Character string. Name of the second variable (observation 2) in `data`.}

\item{var_name}{Optional character string. Custom name for the variable to display in the table. Default is `var1 vs var2`.}

\item{alternative}{Character string specifying the alternative hypothesis. One of `"two.sided"`, `"less"`, or `"greater"`. Default is `"two.sided"`.}

\item{conf.level}{Confidence level for the interval. Default is 0.95.}
}
\value{
A one-row data frame with columns:
\itemize{
  \item `Variable` - variable name
  \item `Mean_obs1` - mean of observation 1
  \item `Mean_obs2` - mean of observation 2
  \item `Mean_diff` - mean difference (obs1 - obs2)
  \item `t_value` - t statistic
  \item `df` - degrees of freedom
  \item `p_value` - p-value
  \item `CI_lower` - lower bound of confidence interval
  \item `CI_upper` - upper bound of confidence interval
}
}
\description{
This function performs a paired t-test between two numeric variables in a data frame
and returns a one-row summary table including means, mean difference, t-value, degrees of freedom,
p-value, and confidence interval.
}
\examples{
# example data
df <- data.frame(
  before = c(10, 12, 14, 15, 11),
  after  = c(11, 13, 13, 16, 12)
)

# Run the paired t-test summary
make_paired_t_test_table(df, var1 = "before", var2 = "after")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_reverse_score.R
\name{make_reverse_score}
\alias{make_reverse_score}
\title{Create Reverse Scores as New Columns}
\usage{
make_reverse_score(data, vars, min_val, max_val, suffix = "_rev")
}
\arguments{
\item{data}{A data frame.}

\item{vars}{A character vector of column names to reverse.}

\item{min_val}{The minimum possible score of the scale.}

\item{max_val}{The maximum possible score of the scale.}

\item{suffix}{A character string to append to the new column names. Defaults to "_rev".}
}
\value{
A data frame containing the original data plus the new reversed columns.
}
\description{
Create Reverse Scores as New Columns
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_demographic_table.R
\name{make_demographic_table}
\alias{make_demographic_table}
\title{Create a demographics summary table}
\usage{
make_demographic_table(data, vars, continuous_vars = NULL)
}
\arguments{
\item{data}{A data frame}

\item{vars}{demographic variables to include in the table}

\item{continuous_vars}{Optional subset of vars to be treated as continuous}
}
\value{
A gtsummary table
}
\description{
Create a demographics summary table
}
\examples{
df <- data.frame(
  age = c("25", "30 years", "35", " 40 ", "22.5", "28+", NA, ""),
  sex = c("M", "F", "m", "f", " M ", "F", "m", NA),
  education = c("HS", "BA", "MA", "ma", "Hs", "Ma", "Ba Bed", "Msc bed ")
)

# Generate a demographic summary table (assign to object to avoid printing)
demo_table <- make_demographic_table(df, vars = c("age", "sex", "education"))
demo_table # optionally inspect the table

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_normality_table.R
\name{make_normality_table}
\alias{make_normality_table}
\title{Make Normality Table}
\usage{
make_normality_table(data, vars = NULL)
}
\arguments{
\item{data}{A data frame.}

\item{vars}{Character vector of variable names. If NULL, all columns are used.}
}
\value{
A data frame with W/D statistics and p-values for both tests.
}
\description{
Computes Shapiro-Wilk and Kolmogorov-Smirnov normality tests for specified variables.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_demographic_table_to_output.R
\name{make_demographic_table_to_output}
\alias{make_demographic_table_to_output}
\title{Create and Export Demographic Summary Table}
\usage{
make_demographic_table_to_output(
  data,
  vars,
  continuous_vars = NULL,
  file_name = "demographic_table",
  format = c("word", "excel", "csv"),
  path = NULL
)
}
\arguments{
\item{data}{A data frame containing the dataset.}

\item{vars}{Character vector of variable names to include in the
demographic summary.}

\item{continuous_vars}{Optional character vector specifying which
variables should be treated as continuous.
If `NULL`, numeric variables are automatically detected.}

\item{file_name}{Name of the output file WITHOUT extension
(e.g., "demographics").}

\item{format}{Output format. Must be one of:
\itemize{
  \item `"word"`  - exports to a Word document (.docx)
  \item `"excel"` - exports to an Excel file (.xlsx)
  \item `"csv"`   - exports to a CSV file (.csv)
}}

\item{path}{Optional character string specifying the directory where the
file should be saved. If `NULL` (default), the file is written to a
temporary directory. Provide a full directory path or use getwd()
during the function call.}
}
\value{
Invisibly returns the full file path to the generated output file.
}
\description{
Generates a demographic summary table using `make_demographic_table()`
and exports the resulting table to Word, Excel, or CSV format.

This is a convenience wrapper that combines analysis and output
in a single step for users who want immediate file export.
}
\details{
The demographic table includes:
\itemize{
  \item Categorical variables reported as n (%)
  \item Continuous variables reported as Mean (SD)
}

Word export uses `flextable` and `officer` for formatting.
Excel export uses `openxlsx`.
CSV export uses base R `write.csv()`.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_correlation_table.R
\name{make_correlation_table}
\alias{make_correlation_table}
\title{Make Correlation Table}
\usage{
make_correlation_table(data, vars = NULL, method = "pearson")
}
\arguments{
\item{data}{A data frame.}

\item{vars}{Character vector of variable names. If NULL, all columns are used.}

\item{method}{Correlation method: "pearson" (default), "spearman", or "kendall".}
}
\value{
A character data frame with correlations and significance stars.
}
\description{
Computes a correlation matrix with inline significance stars.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_EFA_factorability_table.R
\name{make_EFA_factorability_table}
\alias{make_EFA_factorability_table}
\title{Check EFA Factorability and Return Summary Table}
\usage{
make_EFA_factorability_table(data, items, scale_name = "Overall")
}
\arguments{
\item{data}{A data frame containing the variables.}

\item{items}{A character vector of column names to be included in the analysis.}

\item{scale_name}{Character. A label for the scale (e.g., "GLPFS"). Defaults to "Overall".}
}
\value{
A data frame with one row containing the scale-level factorability diagnostics.
}
\description{
This function calculates the overall Kaiser-Meyer-Olkin (KMO) MSA,
Bartlett's Test of Sphericity, and the Determinant of the correlation matrix.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_citation_to_output.R
\name{make_citation_to_output}
\alias{make_citation_to_output}
\title{Export Session Package Citations to Multiple Formats}
\usage{
make_citation_to_output(
  filename = "Session_Citations",
  format = "csv",
  path = NULL,
  packages = NULL
)
}
\arguments{
\item{filename}{A character string specifying the name of the output file.
Defaults to "Session_Citations".}

\item{format}{A character string specifying the output format:
"csv", "word", "excel", or "pdf". Defaults to "csv".}

\item{path}{A character string specifying the directory path for the output.
If NULL (default), it uses a temporary directory. Use "getwd()" for the
current working directory.}

\item{packages}{A character vector of package names to extract citations for.
If NULL (default), citations are extracted for all currently loaded packages
in the session, including base R. Example: \code{packages = c("lavaan", "psych")}.}
}
\value{
The file path of the created document (invisibly).
}
\description{
This function identifies all currently loaded external packages in the current R session,
along with base R, and extracts their citation information. It generates both
plain text and BibTeX formats and exports them using the package's internal
export utility.
}
\examples{
\dontrun{
# Export citations for currently loaded packages to a docs
make_citation_to_output(filename = "My_References", format = "word")

# Export citations for selected packages to a docs in current working directory
make_citation_to_output( packages = c("base","psych","ggplot2"),
                         filename = "Selected_References",
                         format = "word",
                         path = getwd())


# Export to Excel in the current working directory
make_citation_to_output(format = "excel", path = "getwd()")

}

}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/scaledescr.R
\name{scaledescr}
\alias{scaledescr}
\title{scaledescr}
\description{
Provides helper functions to format and summarise already computed outputs from commonly used statistical and psychometric functions into compact, single-row tables and simple graphs. Functions such as make_scale_description_table(), make_demographic_table(), make_alpha_table(), make_paired_t_test_table(), and make_dataframe_to_output() organise results obtained from existing functions including psych::describe(), psych::alpha(), stats::t.test(), and gtsummary::tbl_summary() for streamlined reporting and export to CSV, Word, and Excel formats. The package does not implement new statistical methods or perform additional estimation.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_ICC.R
\name{compute_ICC}
\alias{compute_ICC}
\title{Compute Intraclass Correlation Coefficient (ICC) for Selected Columns}
\usage{
compute_ICC(data, items, check_numeric = TRUE, lmer = FALSE, ...)
}
\arguments{
\item{data}{A data frame containing the ratings or measurements.}

\item{items}{A character vector specifying column names for which
ICC should be calculated (e.g., raters or repeated measurements).}

\item{check_numeric}{Logical. If \code{TRUE} (default), ensures all
selected columns are numeric.}

\item{lmer}{Logical. Passed to \code{psych::ICC()}. Default is FALSE.}

\item{...}{Additional arguments passed to \code{psych::ICC()}.}
}
\value{
An object returned by \code{psych::ICC()}, typically a list
  containing a results table with ICC estimates, F statistics,
  confidence intervals, and model details.
}
\description{
Computes Intraclass Correlation Coefficients (ICC) for a specified set
of numeric variables within a data frame using \code{psych::ICC()}.

This function standardizes column selection and basic validation while
delegating all statistical estimation to \code{psych::ICC()}.
}
\details{
The function does not choose or filter specific ICC models.
All available ICC types (e.g., ICC1, ICC2, ICC3, single and average)
are returned exactly as produced by \code{psych::ICC()}.

Users are responsible for:
\itemize{
  \item Choosing the appropriate ICC model for their study design.
  \item Ensuring assumptions (e.g., continuous ratings, independence).
  \item Handling missing data appropriately.
}
}
\seealso{
\code{\link[psych]{ICC}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_independent_t_test_table.R
\name{make_independent_t_test_table}
\alias{make_independent_t_test_table}
\title{Create a one-row summary table for an independent-samples t-test}
\usage{
make_independent_t_test_table(data, outcome, group)
}
\arguments{
\item{data}{A data frame containing the outcome and grouping variables.}

\item{outcome}{Character string specifying the numeric outcome variable.}

\item{group}{Character string specifying the grouping variable. Must have exactly two levels.}
}
\value{
A single-row data frame with the following columns:
\itemize{
  \item \code{test}: Name of the statistical test
  \item \code{group1}, \code{group2}: Group labels
  \item \code{mean_diff}: Mean difference between groups (group1 - group2)
  \item \code{t_value}: t statistic
  \item \code{df}: Degrees of freedom
  \item \code{p_value}: p-value
  \item \code{n_group1}, \code{n_group2}: Sample sizes per group
  \item \code{cohens_d}: Cohen's d effect size
  \item \code{interpretation}: Qualitative interpretation of effect size
}
}
\description{
This function performs an independent-samples t-test (Welch's t-test by default)
between two groups defined by a binary grouping variable and returns a
single-row data frame. The output includes group names,
sample sizes, mean difference, test statistics, p-value, and effect size
(Cohen's d) with a qualitative interpretation.
}
\details{
The function is intended for streamlined reporting and does not introduce
new statistical methods. All computations rely on \code{stats::t.test()}.


Welch’s t-test is used by default, which does not assume equal variances.
Cohen’s d is computed using the pooled standard deviation for comparability
with conventional benchmarks. Group ordering follows the factor level order
of the grouping variable.
}
\examples{
set.seed(123)

data_t <- data.frame(
  group = rep(c("CBT", "Psychodynamic"), each = 30),
  score = c(
    rnorm(30, mean = 18, sd = 4),
    rnorm(30, mean = 21, sd = 4)
  )
)

make_independent_t_test_table(
  data = data_t,
  outcome = "score",
  group = "group"
)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_scale_description_table.R
\name{make_scale_description_table}
\alias{make_scale_description_table}
\title{Create Descriptive Table for Multiple Scale Columns}
\usage{
make_scale_description_table(
  x = NULL,
  data = NULL,
  columns = NULL,
  scale_names = NULL,
  type = NULL
)
}
\arguments{
\item{x}{Optional numeric vector of total scores (single column, old-style).}

\item{data}{Optional data frame containing one or more scale columns.}

\item{columns}{Optional character vector of column names in `data` (new-style).}

\item{scale_names}{Optional character vector of names for each scale. Defaults to column names.}

\item{type}{"summary" for base::summary(), NULL (default) uses psych::describe().}
}
\value{
A data frame with one row per column, containing descriptive statistics.
}
\description{
Computes descriptive statistics for one or more scale total columns.
Accepts either a numeric vector (single column) or a data frame with column names.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_lavaan_analysis_tables.R
\name{make_lavaan_analysis_tables}
\alias{make_lavaan_analysis_tables}
\title{Comprehensive Lavaan Regression Analysis}
\usage{
make_lavaan_analysis_tables(data, dvs, ivs, standardize = FALSE)
}
\arguments{
\item{data}{A dataframe.}

\item{dvs}{A character vector of one or more Dependent Variables.}

\item{ivs}{A character vector of one or more Independent Variables.}

\item{standardize}{Logical. If TRUE, standardizes data before analysis.}
}
\value{
A list with two dataframes: 'Regression' and 'Fit'.
}
\description{
Fits a lavaan model and returns a list containing the regression
coefficients table and the global model fit indices.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_scale_total.R
\name{make_scale_total}
\alias{make_scale_total}
\title{Compute Scale Total Score}
\usage{
make_scale_total(data, vars, new_var)
}
\arguments{
\item{data}{A data frame.}

\item{vars}{A character vector of column names to be summed.}

\item{new_var}{A single character string specifying the name of the
new total score column.}
}
\value{
The input data frame with one additional numeric column.
}
\description{
Computes the total score for a psychometric scale by summing specified
numeric variables. The resulting total score is appended as a new column
to the input data frame. Missing values are handled using `na.rm = TRUE`.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_alpha_table.R
\name{make_alpha_table}
\alias{make_alpha_table}
\title{Wrap a pre computed psych::alpha object into a single row table with N and alpha only.}
\usage{
make_alpha_table(alpha_res, scale_name = "Scale")
}
\arguments{
\item{alpha_res}{A psych::alpha object (already computed)}

\item{scale_name}{Name of the scale (default: "Scale")}
}
\value{
A data frame with three columns: Scale,N, and Alpha.
}
\description{
Extracts only the Scale Name, Sample Size (N), and Cronbach's Alpha
from a `psych::alpha` object.
}
\examples{
\dontrun{
library(psych)
res <- psych::alpha(mtcars[,1:3])
make_alpha_table(res, scale_name = "Car Scale")
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_alphanumeric_conversion.R
\name{make_alphanumeric_conversion}
\alias{make_alphanumeric_conversion}
\title{Convert Between Alphabetical and Numeric Responses}
\usage{
make_alphanumeric_conversion(
  data,
  column_vars,
  from_values,
  to_values,
  new_names = NULL,
  case_sensitive = FALSE
)
}
\arguments{
\item{data}{A data frame.}

\item{column_vars}{Character vector of column names to convert.}

\item{from_values}{Vector of values to replace (character or numeric).}

\item{to_values}{Vector of replacement values (must be same length as from_values).}

\item{new_names}{Optional character vector of new column names.
If NULL (default), original columns are overwritten.}

\item{case_sensitive}{Logical. Only relevant when converting character values.
Default is FALSE.}
}
\value{
A data frame with converted values.
}
\description{
Converts specified columns between alphabetical (text) and numeric values.
Can either overwrite existing columns or create new ones.
}
\details{
Factors are automatically converted to character before matching.
Unmatched values become NA with a warning.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_dataframe_to_output.R
\name{make_dataframe_to_output}
\alias{make_dataframe_to_output}
\title{Export a data frame to CSV, Word (.docx),Excel (.xlsx) or pdf format.}
\usage{
make_dataframe_to_output(data, filename = NULL, format = "csv", path = NULL)
}
\arguments{
\item{data}{A data frame to export.}

\item{filename}{Optional base file name (without extension). Defaults to object name.
(without path and without extension).
If not provided, the name of the input object is used.}

\item{format}{Character string specifying the output format. One of
`"csv"`, `"word"`,`"excel"` or `"pdf"`. Default is `"csv"`.}

\item{path}{Optional character string specifying the directory where the
file should be saved. If `NULL` (default), the file is written to a
temporary directory. Use `path = getwd()` to save the file in the current
working directory, or provide a full directory path.}
}
\value{
Invisibly returns the full file path to the generated output file.
}
\description{
If no output path is specified, the file is written to a temporary directory
using `tempdir()`.
For reproducible workflows, users are encouraged to explicitly specify an output location, either the current working directory
or a full file path.
}
\details{
- CSV files are written using `utils::write.csv()`
- Word files (`docx`) are created using the `officer` package
- Excel (`xlsx`) files are created using the `openxlsx` package
- PDF files are created using the 'flextable' package
}
\note{
Exporting to PDF requires the 'webshot2' package to be installed.
}
\examples{
\dontrun{

# Example dataset available in base R
data_df <- head(mtcars)

#--------------------------------------------------
# 1. Simplest use: export to CSV in temp directory
#--------------------------------------------------
make_dataframe_to_output(data_df)

#--------------------------------------------------
# 2. Specify filename
#--------------------------------------------------
make_dataframe_to_output(
  data = data_df,
  filename = "mtcars_sample"
)

#--------------------------------------------------
# 3. Export as Word document
#--------------------------------------------------
make_dataframe_to_output(
  data = data_df,
  filename = "mtcars_word_table",
  format = "word"
)

#--------------------------------------------------
# 4. Export as Excel file
#--------------------------------------------------
make_dataframe_to_output(
  data = data_df,
  filename = "mtcars_excel_table",
  format = "excel"
)

#--------------------------------------------------
# 5. Save to current working directory
#--------------------------------------------------
make_dataframe_to_output(
  data = data_df,
  filename = "mtcars_current_folder",
  format = "csv",
  path = "getwd()"
)

#--------------------------------------------------
# 6. Save Excel file to current working directory
#--------------------------------------------------
make_dataframe_to_output(
  data = data_df,
  filename = "mtcars_excel_current",
  format = "excel",
  path = "getwd()"
)

#--------------------------------------------------
# 7. Export another base dataset (iris)
#--------------------------------------------------
make_dataframe_to_output(
  data = head(iris),
  filename = "iris_sample",
  format = "word"
)

#--------------------------------------------------
# 8. Using a custom folder path
#--------------------------------------------------
make_dataframe_to_output(
  data = head(airquality),
  filename = "airquality_data",
  format = "excel",
  path = "D:/output_folder"
)

}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_one_sample_t_test_table.R
\name{make_one_sample_t_test_table}
\alias{make_one_sample_t_test_table}
\title{Create a Summary Table for a One-Sample t-test}
\usage{
make_one_sample_t_test_table(t_res, variable_label = "Variable", digits = 3)
}
\arguments{
\item{t_res}{An object of class "htest" produced by \code{t.test()},or a list of such objects.}

\item{variable_label}{A character string to label the tested variable(s).}

\item{digits}{Integer indicating the number of decimal places to round to.}
}
\value{
A data frame summarizing the one-sample t-test results.
}
\description{
Create a Summary Table for a One-Sample t-test
}
\examples{
data("attitude")
A <- as.data.frame(attitude)

# Example 1: One-sample t-test with default mu = 0
t1 <- t.test(A$rating)
make_one_sample_t_test_table(
  t_res = t1,
  variable_label = "Rating"
)

# Example 2: One-sample t-test with specified mu
t2 <- t.test(A$rating, mu = 60)
make_one_sample_t_test_table(
  t_res = t2,
  variable_label = "Rating"
)

# Example 3: Multiple one-sample t-tests combined into one table
t1 <- t.test(A$rating)
t2 <- t.test(A$learning)
t3 <- t.test(A$raises)

make_one_sample_t_test_table(
  t_res = list(t1, t2, t3),
  variable_label = c("Rating", "Learning", "Raises")
)

# Example 4: Multiple tests with different mu values
t1 <- t.test(A$rating, mu = 60)
t2 <- t.test(A$learning, mu = 65)
t3 <- t.test(A$raises, mu = 50)

make_one_sample_t_test_table(
  t_res = list(t1, t2, t3),
  variable_label = c("Rating", "Learning", "Raises (mu = 50)")
)
}
